@@ -94,6 +94,7 @@ typedef struct {
 	CARD8	flag;
 	CARD16	casting_port;
 	CARD32	casting_ip;
+	CARD8	fullscreen;
 	CARD8	src_ID[IDLENGTH];
 	rfbServerInitMsg serverInitMsg;
 } CastAdv;
@@ -203,7 +204,7 @@ extern int ConnectAdv ();
 extern void ConnectCTL (struct sockaddr_in, int, int);
 extern void ConnectVNC (struct sockaddr_in, int, int);
 int CreateMultiSockToSend (unsigned int ip, int port);
-extern void SendCastMsg (char flag, int clientNum);
+extern void SendCastMsg (char flag, int clientNum, char fullscreen);
 extern void SendLockMsg (char flag, int clientNum);
 extern void SendAllowMsg (int clientNum, char *buf);
 extern void CutVNC (int clientNum);
