@@ -30,7 +30,7 @@ void CheckLockClient(void);
 
 int getClientFromCtldsp (int fd);
 int getClientFromVncdsp (int fd);
-void SendCastMsg (char flag, int clientNum);
+void SendCastMsg (char flag, int clientNum, char fullscreen);
 int ConnectMyself ();
 Bool AuthDB (char *client_ID);
 
@@ -423,8 +423,8 @@ void
 controlSocketCallback (gpointer clientData, gint fd, GdkInputCondition condition)
 {
   clientNum = getClientFromCtldsp (fd);
-  gdk_input_remove(server_CB.client_grp[clientNum]->g_ctldsp);
   if (clientNum == EMPTY) return;
+  gdk_input_remove(server_CB.client_grp[clientNum]->g_ctldsp);
   int socket = server_CB.client_grp[clientNum]->ctldsp;
   char buf[64];
 
@@ -500,7 +500,7 @@ controlSocketCallback (gpointer clientData, gint fd, GdkInputCondition condition
       break;
 
     case rfbClientExist:
-      server_CB.client_grp[clientNum]->state &= 0x3f | (buf[1] & 0xc0);
+      server_CB.client_grp[clientNum]->state &= 0xbf | (buf[1] & 0x40);
 
       struct timeval tmptime;
       gettimeofday(&timenow, 0);
@@ -526,6 +526,7 @@ vncSocketCallback (gpointer clientData, gint fd, GdkInputCondition condition)
 {
   sem_lock ();
   clientNum = getClientFromVncdsp (fd);
+  if (clientNum == EMPTY) return;
   gdk_input_remove(server_CB.client_grp[clientNum]->g_vncdsp);
   page = server_CB.client_grp[clientNum]->draw_page;
   da_num = server_CB.client_grp[clientNum]->draw_area;
@@ -748,7 +749,7 @@ CutVNC (int clientNum)
 }
 
 void 
-SendCastMsg (char flag, int clientNum)
+SendCastMsg (char flag, int clientNum, char fullscreen)
 {
   CastAdv castadv;
   int len;
@@ -759,6 +760,7 @@ SendCastMsg (char flag, int clientNum)
   castadv.flag = flag;
   castadv.casting_ip = server_CB.casting_ip[server_CB.client_grp[clientNum]->recv_grp];
   castadv.casting_port = server_CB.casting_port;
+  castadv.fullscreen = fullscreen;
 
   for (i = 0; i < MAXCLIENT; i++) {
     if (server_CB.client_grp[i]->cast_grp == server_CB.client_grp[clientNum]->recv_grp) {
